proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-23 by code2llm · Primary language: python · Python: 154, JavaScript: 67, Shell: 8

1,792
Functions
140
Classes
207
Files
51,011
Lines
3
Languages
4.3
Avg CC
151
Critical (CC≥10)
0
Duplicates
0
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution

## Top Modules (229)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
tools.jsx | src/proxym/dashboard/components | 1,486 | 108 | 0 | 76
tickets.jsx | src/proxym/dashboard/components | 1,444 | 87 | 0 | 94
tasks.jsx | src/proxym/dashboard/components | 963 | 69 | 0 | 64
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
environments.jsx | src/proxym/dashboard/components | 541 | 22 | 0 | 50
validate_system.sh | scripts | 531 | 11 | 0 | 0
setup.jsx | src/proxym/dashboard/components | 519 | 27 | 0 | 16
__init__.py | src/proxym/tools | 492 | 15 | 5 | 9
projects.jsx | src/proxym/dashboard/components | 467 | 22 | 0 | 21
_tickets_api.py | src/proxym/dashboard | 454 | 20 | 8 | 15
users.jsx | src/proxym/dashboard/components | 427 | 21 | 0 | 21
__init__.py | src/proxym/accounts | 398 | 20 | 8 | 15
_manager.py | src/proxym/dashboard/tickets | 387 | 33 | 1 | 22
_environments_api.py | src/proxym/dashboard | 376 | 29 | 6 | 8
human.jsx | src/proxym/dashboard/components | 366 | 18 | 0 | 65
__init__.py | src/proxym/router | 352 | 13 | 1 | 9
users.py | src/proxym/dashboard | 349 | 19 | 3 | 9
repair_agent.py | src/proxym/observability | 341 | 9 | 1 | 14
__init__.py | src/proxym/cache | 333 | 10 | 3 | 9
entrypoint.sh | services/vscode | 333 | 1 | 0 | 0

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | TicketDetailPanel | cc_exceeded | 94 | 15
critical | TicketsPanel | cc_exceeded | 87 | 15
critical | ToolHealthPanel | cc_exceeded | 76 | 15
critical | TicketDispatchTable | cc_exceeded | 73 | 15
critical | JobDetailsPanel | cc_exceeded | 67 | 15
critical | HumanTaskPanel | cc_exceeded | 65 | 15
critical | TasksPanel | cc_exceeded | 64 | 15
critical | TicketsPanel | high_fan_out | 56 | 10
critical | ToolsPanel | cc_exceeded | 51 | 15
critical | EnvironmentsPanel | cc_exceeded | 50 | 15
critical | ToolsJobQueue | cc_exceeded | 48 | 15
critical | TicketHistoryItem | cc_exceeded | 42 | 15
critical | TasksRecentJobs | cc_exceeded | 37 | 15
critical | HumanJobsList | cc_exceeded | 37 | 15
critical | EnvironmentsPanel | high_fan_out | 37 | 10

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
TicketsPanel | 56 | Orchestrates 56 calls
EnvironmentsPanel | 37 | Orchestrates 37 calls
useDashboardData | 33 | Orchestrates 33 calls
VoiceChat | 31 | Orchestrates 31 calls
create_ticket | 29 | Create a new ticket. Accepts 'task' (new) or 'title' (legacy).
run_all_tests | 28 | Run all diagnostic tests and return comprehensive status.
chat_completions | 27 | OpenAI-compatible chat completions with intelligent routing. Extra headers: X
QuickTaskCreator | 27 | Orchestrates 27 calls
TicketDispatchTable | 27 | 27-way dispatch
ToolHealthPanel | 26 | Orchestrates 26 calls

## Refactoring Priorities (15)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split _apply_runtime_health (CC=28 → target CC<10) | high | low
2 | Split DiagnosticsPanel (CC=26 → target CC<10) | high | low
3 | Split LogPanel (CC=34 → target CC<10) | high | low
4 | Split HumanTaskPanel (CC=65 → target CC<10) | high | low
5 | Split VMsPanel (CC=32 → target CC<10) | high | low
6 | Split TaskJobBadge (CC=25 → target CC<10) | high | low
7 | Split QuickTaskCreator (CC=27 → target CC<10) | high | low
8 | Split TasksPanel (CC=64 → target CC<10) | high | low
9 | Split JobRow (CC=26 → target CC<10) | high | low
10 | Split JobDetailsPanel (CC=67 → target CC<10) | high | low
11 | Split TicketDispatchTable (CC=73 → target CC<10) | high | low
12 | Split ToolHealthPanel (CC=76 → target CC<10) | high | low
13 | Split ToolsPanel (CC=51 → target CC<10) | high | low
14 | Split TicketCard (CC=31 → target CC<10) | high | low
15 | Split TicketHistoryItem (CC=42 → target CC<10) | high | low